angular.module('wechat.services', [])

.factory("userService", function($http) {
    var users = [];
    return {
        getUsers: function() {
            return $http.get("https://randomuser.me/api/?results=10").then(function(response) {
                users = response.data.results;
                return response.data.results;
            });
        },
        getUser: function(index) {
            return users[index];
        }
    };
})

.factory('localStorageService', [function() {
        return {
            get: function localStorageServiceGet(key, defaultValue) {
                var stored = localStorage.getItem(key);
                try {
                    stored = angular.fromJson(stored);
                } catch (error) {
                    stored = null;
                }
                if (defaultValue && stored === null) {
                    stored = defaultValue;
                }
                return stored;
            },
            update: function localStorageServiceUpdate(key, value) {
                if (value) {
                    localStorage.setItem(key, angular.toJson(value));
                }
            },
            clear: function localStorageServiceClear(key) {
                localStorage.removeItem(key);
            }
        };
    }])
    .factory('dateService', [function() {
        return {
            handleMessageDate: function(messages) {
                var i = 0,
                    length = 0,
                    messageDate = {},
                    nowDate = {},
                    weekArray = ["周日", "周一", "周二", "周三", "周四", "周五", "周六"],
                    diffWeekValue = 0;
                if (messages) {
                    nowDate = this.getNowDate();
                    length = messages.length;
                    for (i = 0; i < length; i++) {
                        messageDate = this.getMessageDate(messages[i]);
                        if (!messageDate) {
                            return null;
                        }
                        if (nowDate.year - messageDate.year > 0) {
                            messages[i].lastMessage.time = messageDate.year + "";
                            continue;
                        }
                        if (nowDate.month - messageDate.month >= 0 ||
                            nowDate.day - messageDate.day > nowDate.week) {
                            messages[i].lastMessage.time = messageDate.month +
                                "月" + messageDate.day + "日";
                            continue;
                        }
                        if (nowDate.day - messageDate.day <= nowDate.week &&
                            nowDate.day - messageDate.day > 1) {
                            diffWeekValue = nowDate.week - (nowDate.day - messageDate.day);
                            messages[i].lastMessage.time = weekArray[diffWeekValue];
                            continue;
                        }
                        if (nowDate.day - messageDate.day === 1) {
                            messages[i].lastMessage.time = "昨天";
                            continue;
                        }
                        if (nowDate.day - messageDate.day === 0) {
                            messages[i].lastMessage.time = messageDate.hour + ":" + messageDate.minute;
                            continue;
                        }
                    }
                    // console.log(messages);
                    // return messages;
                } else {
                    console.log("messages is null");
                    return null;
                }

            },
            getNowDate: function() {
                var nowDate = {};
                var date = new Date();
                nowDate.year = date.getFullYear();
                nowDate.month = date.getMonth();
                nowDate.day = date.getDate();
                nowDate.week = date.getDay();
                nowDate.hour = date.getHours();
                nowDate.minute = date.getMinutes();
                nowDate.second = date.getSeconds();
                return nowDate;
            },
            getMessageDate: function(message) {
                var messageDate = {};
                var messageTime = "";
                //2015-10-12 15:34:55
                var reg = /(^\d{4})-(\d{1,2})-(\d{1,2})\s(\d{1,2}):(\d{1,2}):(\d{1,2})/g;
                var result = new Array();
                if (message) {
                    messageTime = message.lastMessage.originalTime;
                    result = reg.exec(messageTime);
                    if (!result) {
                        console.log("result is null");
                        return null;
                    }
                    messageDate.year = parseInt(result[1]);
                    messageDate.month = parseInt(result[2]);
                    messageDate.day = parseInt(result[3]);
                    messageDate.hour = parseInt(result[4]);
                    messageDate.minute = parseInt(result[5]);
                    messageDate.second = parseInt(result[6]);
                    // console.log(messageDate);
                    return messageDate;
                } else {
                    console.log("message is null");
                    return null;
                }
            }
        };
    }])
    .factory('messageService', ['localStorageService', 'dateService',
        function(localStorageService, dateService) {
            return {
                init: function(messages) {
                    var i = 0;
                    var length = 0;
                    var messageID = new Array();
                    var date = null;
                    var messageDate = null;
                    if (messages) {
                        length = messages.length;
                        for (; i < length; i++) {
                            messageDate = dateService.getMessageDate(messages[i]);
                            if (!messageDate) {
                                return null;
                            }
                            date = new Date(messageDate.year, messageDate.month,
                                messageDate.day, messageDate.hour, messageDate.minute,
                                messageDate.second);
                            messages[i].lastMessage.timeFrome1970 = date.getTime();
                            messageID[i] = {
                                id: messages[i].id
                            };

                        }
                        localStorageService.update("messageID", messageID);
                        for (i = 0; i < length; i++) {
                            localStorageService.update("message_" + messages[i].id, messages[i]);
                        }
                    }
                },
                getAllMessages: function() {
                    var messages = new Array();
                    var i = 0;
                    var messageID = localStorageService.get("messageID");
                    var length = 0;
                    var message = null;
                    if (messageID) {
                        length = messageID.length;

                        for (; i < length; i++) {
                            message = localStorageService.get("message_" + messageID[i].id);
                            if (message) {
                                messages.push(message);
                            }
                        }
                        dateService.handleMessageDate(messages);
                        return messages;
                    }
                    return null;

                },
                getMessageById: function(id) {
                    return localStorageService.get("message_" + id);
                },
                getAmountMessageById: function(num, id) {
                    var messages = [];
                    var message = localStorageService.get("message_" + id).message;
                    var length = 0;
                    if (num < 0 || !message) return;
                    length = message.length;
                    if (num < length) {
                        messages = message.splice(length - num, length);
                        return messages;
                    } else {
                        return message;
                    }
                },
                updateMessage: function(message) {
                    var id = 0;
                    if (message) {
                        id = message.id;
                        localStorageService.update("message_" + id, message);
                    }
                },
                deleteMessageId: function(id) {
                    var messageId = localStorageService.get("messageID");
                    var length = 0;
                    var i = 0;
                    if (!messageId) {
                        return null;
                    }
                    length = messageId.length;
                    for (; i < length; i++) {
                        if (messageId[i].id === id) {
                            messageId.splice(i, 1);
                            break;
                        }
                    }
                    localStorageService.update("messageID", messageId);
                },
                clearMessage: function(message) {
                    var id = 0;
                    if (message) {
                        id = message.id;
                        localStorageService.clear("message_" + id);
                    }
                }
            };
        }
    ])
    .factory('$data', function($http) {
        return {
            findAll: function(tableName, requestParams) {
                var url = config.basePath + tableName + "/findAll.do?callback=JSON_CALLBACK";
                return $http.jsonp(url, { params: requestParams });

            },
            findAllByPage: function(tableName, requestParams) {
                var url = config.basePath + tableName + "/findAllByPage.do?callback=JSON_CALLBACK";
                return $http.jsonp(url, { params: requestParams });

            },
            login: function(tableName, requestParams) {
                var url = config.basePath + tableName + "/login.do?phoneNumber=" + requestParams.phoneNumber + "&password=" + requestParams.password + "&callback=JSON_CALLBACK";
                return $http.jsonp(url);
            },
            register: function(tableName, requestParams) {
                var url = config.basePath + tableName + "/register.do?callback=JSON_CALLBACK";
                return $http.jsonp(url, { params: requestParams });
            },
            modifyPassword: function(tableName, requestParams) {
                var url = config.basePath + tableName + "/modifyPassword.do?callback=JSON_CALLBACK";
                return $http.jsonp(url, { params: requestParams });
            },
            getCheckCode: function(tableName) {
                var url = config.basePath + tableName + "/getCheckCode.do?callback=JSON_CALLBACK";
                return $http.jsonp(url);
            },

            findById: function(tableName, id) {
                var url = config.basePath + tableName + "/findById.do?id=" + id + "&callback=JSON_CALLBACK";
                return $http.jsonp(url);

            },
            findByConditions: function(tableName, requestParams) {
                var url = config.basePath + tableName + "/findByConditions.do?callback=JSON_CALLBACK";
                return $http.jsonp(url, { params: requestParams });
            },

            remove: function(twzx) {
                twzxs.splice(twzxs.indexOf(twzx), 1);
            },

            add: function(tableName, postData) {
                var url = config.basePath + tableName + "/add.do?callback=JSON_CALLBACK";
                return $http.jsonp(url, { params: postData });
            },
            getmessage: function() {
                var url = "http://liu-pc.sdc.cnki.net:8090/Tes/json?callback=JSON_CALLBACK";
                return $http.jsonp(url, {});
            }
        }

    })
    //正則驗證
    .factory("regular", function() {
        return {
            single: function(str, reg) {
                if (str.match(reg)) {
                    return true;
                } else {
                    return false;
                }
            },
            many: function(strArr, regArr, status) {
                if (!angular.isNumber(status)) status = 0;
                var result = {};
                angular.forEach(strArr, function(n, i) {
                    result[i] = {};
                    angular.forEach(regArr, function(nn, ii) {
                        result[i][ii] = n.match(nn);
                    });
                });
                if (status == 0) { //0 一条str对一条reg
                    return result[0][0];
                } else if (status == 1) { //1 一条str对多条reg 或运算
                    var bool = false;
                    angular.forEach(result, function(n, i) {
                        angular.forEach(n, function(nn, ii) {
                            bool = bool || nn;
                        });
                    });
                    return bool;
                } else if (status == 2) { //2 多条str对一条reg
                    angular.forEach(result, function(n, i) {
                        result[i] = result[i][0];
                    });
                    return result;
                }
            },
            //常用的验证
            //身份证验证
            idcard: function(str) {
                return this.many([str], [/^[1-9]\d{7}((0\d)|(1[0-2]))(([0|1|2]\d)|3[0-1])\d{3}$/, /^[1-9]\d{5}[1-9]\d{3}((0\d)|(1[0-2]))(([0|1|2]\d)|3[0-1])((\d{4})|\d{3}[A-Z])$/], 1);
            },
            //手机号码验证
            telphone: function(str) {
                return this.single(str, /^1[3|4|5|7|8]\d{9}$/);
            },
            //银行卡验证
            bankcard: function(str) {
                return this.single(str.toString(), /^\d{16}|\d{19}$/);
            }
        }
    })
    //加载中
    .factory("load", function($ionicLoading) {
        return {
            show: function(str) {
                $ionicLoading.show({
                    template: '<ion-spinner icon="ios" style="width:32px"></ion-spinner></br>'+str ,
                     maxWidth: 300,
                });
            },
            hide: function() {
                $ionicLoading.hide();
            }
        }
    })
    //弹窗
    .factory("alert", function($ionicPopup, $timeout) {
        var alertElement;
        return {
            /*
            obj.title //标题
            obj.template  //内容
            obj.time //若有数值执行定时关闭
            */
            show: function(obj) {
                alertElement = $ionicPopup.alert({
                    title: obj.title || "提示信息",
                    template: obj.template || "<p>提示</p>",
                    buttons: [{
                        text: "确定",
                        type: "button-positive"
                    }]
                });
                if (angular.isNumber(obj.time)) {
                    $timeout(this.hide, obj.time);
                }
            },
            hide: function() {
                alertElement.close();
            }
        }
    });
